pub struct EmailServiceAssertions { /* private fields */ }Expand description
Email service assertion helpers
Implementations
Sourceimpl EmailServiceAssertions
impl EmailServiceAssertions
Sourcepub async fn should_have_sent_email(
&self,
_to: &str,
_subject: &str,
) -> Result<()>
pub async fn should_have_sent_email( &self, _to: &str, _subject: &str, ) -> Result<()>
Assert that an email was sent
Sourcepub async fn should_have_sent_count(&self, _expected_count: i64) -> Result<()>
pub async fn should_have_sent_count(&self, _expected_count: i64) -> Result<()>
Assert that a specific number of emails were sent
Sourcepub async fn should_have_sent_welcome_email(
&self,
_user_email: &str,
) -> Result<()>
pub async fn should_have_sent_welcome_email( &self, _user_email: &str, ) -> Result<()>
Assert that a welcome email was sent to a user