pub struct ServiceConfig {
pub plugin: String,
pub image: Option<String>,
pub args: Option<Vec<String>>,
pub env: Option<HashMap<String, String>>,
pub ports: Option<Vec<u16>>,
pub volumes: Option<Vec<VolumeConfig>>,
pub health_check: Option<HealthCheckConfig>,
pub username: Option<String>,
pub password: Option<String>,
pub strict: Option<bool>,
pub wait_for_span: Option<String>,
pub wait_for_span_timeout_secs: Option<u64>,
}Expand description
Service configuration
Fields
plugin: StringService plugin (generic_container, surrealdb, ollama, etc.)
image: Option<String>Service image (optional for network services)
args: Option<Vec<String>>Service command arguments (v1.0 - default args for service) Can be overridden by scenario.run
env: Option<HashMap<String, String>>Service environment variables
ports: Option<Vec<u16>>Service ports
volumes: Option<Vec<VolumeConfig>>Service volumes
health_check: Option<HealthCheckConfig>Service health check
username: Option<String>SurrealDB username (optional, defaults to root)
password: Option<String>SurrealDB password (optional, defaults to root)
strict: Option<bool>SurrealDB strict mode (optional, defaults to false)
wait_for_span: Option<String>Span name to wait for before marking service as ready Service will poll for this span in OTEL output until detected or timeout
wait_for_span_timeout_secs: Option<u64>Timeout in seconds for waiting for span (default: 30)
Implementations