TemplateRenderer

Struct TemplateRenderer 

pub struct TemplateRenderer { /* private fields */ }
Template renderer with Tera engine

Provides template rendering with custom functions for:

  • Environment variable access
  • Deterministic timestamps
  • SHA-256 hashing
  • TOML encoding
  • Macro library for common TOML patterns

Implementations

Source

impl TemplateRenderer

pub fn new() -> Result<TemplateRenderer, TemplateError>

Create new template renderer with custom functions and macro library

pub fn with_defaults() -> Result<TemplateRenderer, TemplateError>

Create renderer with default PRD v1.0 variable resolution

Initializes context with standard variables resolved via precedence: template vars → ENV → defaults

pub fn with_context(self, context: TemplateContext) -> TemplateRenderer

Set template context variables

pub fn with_determinism( self, determinism: Arc<dyn TimestampProvider + Send + Sync>, ) -> TemplateRenderer

Set determinism engine for reproducible template rendering

When configured, this freezes now_rfc3339() function and provides seeded random generation for fake data functions.

Arguments
  • engine - DeterminismEngine with optional seed and freeze_clock
Returns
  • Self with determinism enabled
Example
use clnrm_core::template::TemplateRenderer;
use clnrm_core::determinism::{DeterminismEngine, DeterminismConfig};

let config = DeterminismConfig {
    seed: Some(42),
    freeze_clock: Some("2025-01-01T00:00:00Z".to_string()),
};
let engine = DeterminismEngine::new(config).unwrap();
let renderer = TemplateRenderer::new()
    .unwrap()
    .with_determinism(engine);
pub fn merge_user_vars(&mut self, user_vars: HashMap<String, Value>)

Merge user-provided variables into context (respects precedence)

User variables take highest priority in the precedence chain

pub fn render_file(&mut self, path: &Path) -> Result<String, TemplateError>

Render template file to TOML string

pub fn render_str( &mut self, template: &str, name: &str, ) -> Result<String, TemplateError>

Render template string to TOML

pub fn render_to_format( &mut self, template: &str, name: &str, format: OutputFormat, ) -> Result<String, TemplateError>

Render template to specific output format

Arguments
  • template - Template content
  • name - Template name for error reporting
  • format - Desired output format
pub fn render_template_string( &mut self, template: &str, name: &str, ) -> Result<String, TemplateError>

Render a template string with macro imports (for testing) This is a helper method that handles the add_raw_template + render pattern

pub fn render_from_glob( &mut self, glob_pattern: &str, template_name: &str, ) -> Result<String, TemplateError>

Render template from glob pattern

Useful for rendering multiple templates with shared context

pub fn enable_inheritance(self) -> Result<TemplateRenderer, TemplateError>

Add template inheritance support

Enables {% extends %} and {% block %} functionality

pub fn add_template( &mut self, name: &str, content: &str, ) -> Result<(), TemplateError>

Add template to the renderer

Useful for dynamic template loading and composition

pub fn template_names(&self) -> Vec<&str>

Get available template names

pub fn has_template(&self, name: &str) -> bool

Check if template exists