pub struct TemplateRenderer { /* private fields */ }Expand description
Template renderer with Tera engine
Provides template rendering with custom functions for:
- Environment variable access
- Deterministic timestamps
- SHA-256 hashing
- TOML encoding
- Macro library for common TOML patterns
Implementations
Sourceimpl TemplateRenderer
impl TemplateRenderer
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Create new template renderer with custom functions and macro library
Sourcepub fn with_defaults() -> Result<Self>
pub fn with_defaults() -> Result<Self>
Create renderer with default PRD v1.0 variable resolution
Initializes context with standard variables resolved via precedence: template vars → ENV → defaults
Sourcepub fn with_context(self, context: TemplateContext) -> Self
pub fn with_context(self, context: TemplateContext) -> Self
Set template context variables
Sourcepub fn merge_user_vars(&mut self, user_vars: HashMap<String, Value>)
pub fn merge_user_vars(&mut self, user_vars: HashMap<String, Value>)
Merge user-provided variables into context (respects precedence)
User variables take highest priority in the precedence chain
Sourcepub fn render_file(&mut self, path: &Path) -> Result<String>
pub fn render_file(&mut self, path: &Path) -> Result<String>
Render template file to TOML string