CleanroomEnvironment

Struct CleanroomEnvironment 

pub struct CleanroomEnvironment { /* private fields */ }
Simple environment wrapper around existing infrastructure

Implementations

Source

impl CleanroomEnvironment

pub async fn new() -> Result<Self>

Create a new cleanroom environment

pub async fn execute_test<F, T>( &self, _test_name: &str, test_fn: F, ) -> Result<T>
where F: FnOnce() -> Result<T>,

Execute a test with OTel tracing

pub async fn get_metrics(&self) -> Result<SimpleMetrics>

Get current metrics

pub async fn enable_tracing(&self) -> Result<()>

Enable tracing for this environment

pub async fn enable_metrics(&self) -> Result<()>

Enable metrics collection for this environment

pub async fn get_traces(&self) -> Result<Vec<String>>

Get traces from this environment

pub async fn get_container_reuse_stats(&self) -> (u32, u32)

Get container reuse statistics

pub async fn has_container(&self, name: &str) -> bool

Check if a container with the given name has been created in this session

pub async fn register_service( &self, plugin: Box<dyn ServicePlugin>, ) -> Result<()>

Register a service plugin

pub async fn start_service(&self, service_name: &str) -> Result<ServiceHandle>

Start a service by name

pub async fn stop_service(&self, handle_id: &str) -> Result<()>

Stop a service by handle ID

pub async fn services(&self) -> RwLockReadGuard<'_, ServiceRegistry>

Get service registry (read-only access)

pub async fn register_container<T: Send + Sync + 'static>( &self, name: String, container: T, ) -> Result<()>

Register a container for reuse

pub async fn get_or_create_container<F, T>( &self, name: &str, factory: F, ) -> Result<T>
where F: FnOnce() -> Result<T>, T: Send + Sync + Clone + 'static,

Get or create container with reuse pattern

This method implements true container reuse by storing and returning the actual container instances, providing the promised 10-50x performance improvement.

pub async fn check_health(&self) -> HashMap<String, HealthStatus>

Check health of all services

pub async fn get_service_logs( &self, service_id: &str, lines: usize, ) -> Result<Vec<String>>

Get service logs

pub fn session_id(&self) -> Uuid

Get session ID

pub fn backend(&self) -> &dyn Backend

Get backend

pub async fn execute_in_container( &self, container_name: &str, command: &[String], ) -> Result<ExecutionResult>

Execute a command in a container with proper error handling and observability Core Team Compliance: Async for I/O operations, proper error handling, no unwrap/expect

This method creates a fresh container for each command execution, which is appropriate for testing scenarios where isolation is more important than performance.